module.exports = {
  parser: '@typescript-eslint/parser',
  parserOptions: {
    project: 'tsconfig.json',
    tsconfigRootDir : __dirname, 
    sourceType: 'module',
  },
  plugins: ['@typescript-eslint/eslint-plugin'],
  extends: [
    'plugin:@typescript-eslint/recommended',
    'plugin:prettier/recommended',
  ],
  root: true,
  env: {
    node: true,
    jest: true,
  },
  ignorePatterns: ['.eslintrc.js'],
  rules: {
    '@typescript-eslint/explicit-function-return-type': ['error'],
    '@typescript-eslint/no-explicit-any': ['error'],
    '@typescript-eslint/prefer-nullish-coalescing': ['error'],
    '@typescript-eslint/restrict-plus-operands': ['error'],
    '@typescript-eslint/type-annotation-spacing': ['error'],

    '@typescript-eslint/brace-style': ['error', '1tbs'],
    '@typescript-eslint/comma-spacing': ['error', { 'before': false, 'after': true }],
    '@typescript-eslint/default-param-last': ['error'],
    '@typescript-eslint/dot-notation': ['error'],
    '@typescript-eslint/keyword-spacing': ['error', { 'before': true, 'after': true }],
    '@typescript-eslint/no-empty-function': ['error'],
    '@typescript-eslint/no-extra-semi': ['error'],
    '@typescript-eslint/no-shadow': ['error'],
    '@typescript-eslint/no-unused-expressions': ['error'],
    '@typescript-eslint/no-unused-vars': ['error'],
    '@typescript-eslint/quotes': ['error', 'single'],
    '@typescript-eslint/require-await': ['error'],
    '@typescript-eslint/semi': ['error', 'always'],
    '@typescript-eslint/space-before-blocks': ['error'],

    'no-unreachable': 'error',
    'no-unused-vars': 'off',

    'camelcase': 'error',
    'default-param-last': 'off',
    'dot-notation': 'off',
    'eqeqeq': 'error',
    'no-confusing-arrow': 'error',
    'no-else-return': 'error',
    'no-empty': 'error',
    'no-empty-function': 'off',
    'no-extra-semi': 'off',
    'no-lonely-if': 'error',
    'no-mixed-operators': 'error',
    'no-multi-assign': 'error',
    'no-negated-condition': 'error',
    'no-nested-ternary': 'error',
    'no-param-reassign': 'error',
    'no-shadow': 'off',
    'no-shadow-restricted-names': 'error',
    'no-throw-literal': 'error',
    'no-unneeded-ternary': 'error',
    'no-unused-expressions': 'off',
    'no-useless-rename': 'error',
    'no-useless-return': 'error',
    'no-var': 'error',
    'operator-assignment': ['error', 'always'],
    'prefer-const': 'error',
    'prefer-template': 'error',
    'require-await': 'off',
    'require-yield': 'error',
    'spaced-comment': ['error', 'always'],

    'arrow-parens': ['error', 'always'],
    'arrow-spacing': 'error',
    'block-spacing': 'error',
    'brace-style': 'off',
    'comma-spacing': 'off',
    'comma-style': ['error', 'last'],
    'func-call-spacing': ['error', 'never'],
    'function-call-argument-newline': ['error', 'consistent'],
    'function-paren-newline': ['error', 'consistent'],
    'implicit-arrow-linebreak': ['error', 'beside'],
    'indent': 'off',
    'jsx-quotes': ['error', 'prefer-single'],
    'keyword-spacing': 'off',
    'no-mixed-spaces-and-tabs': 'error',
    'no-multi-spaces': 'error',
    'no-multiple-empty-lines': 'error',
    'no-tabs': 'error',
    'no-trailing-spaces': 'error',
    'no-whitespace-before-property': 'error',
    'quotes': 'off',
    'rest-spread-spacing': ['error', 'never'],
    'semi': 'off',
    'space-before-blocks': 'off',
    'space-in-parens': 'error',
    'switch-colon-spacing': 'error',
    'wrap-regex': 'error',
  },
};
